@@ -10,6 +10,7 @@ from keras_cv_attention_models.attention_layers import (
     batchnorm_with_activation,
     conv2d_no_bias,
     drop_block,
+    global_context_module,
     make_divisible,
     output_block,
     se_module,
@@ -29,6 +30,7 @@ FILE_HASH_DICT = {
     "v2-m": {"21k-ft1k": "0c236c3020e3857de1e5f2939abd0cc6", "21k": "3923c286366b2a5137f39d1e5b14e202", "imagenet": "ac3fd0ff91b35d18d1df8f1895efe1d5"},
     "v2-s": {"21k-ft1k": "93046a0d601da46bfce9d4ca14224c83", "21k": "10b05d878b64f796ab984a5316a4a1c3", "imagenet": "3b91df2c50c7a56071cca428d53b8c0d"},
     "v2-t": {"imagenet": "4a0ff9cb396665734d7ca590fa29681b"},
+    "v2-t-gc": {"imagenet": "653fc06396f9503dff61aa17c40b2443"},
     "v2-xl": {"21k-ft1k": "9aaa2bd3c9495b23357bc6593eee5bce", "21k": "c97de2770f55701f788644336181e8ee"},
     "v1-b0": {"noisy_student": "d125a518737c601f8595937219243432", "imagenet": "cc7d08887de9df8082da44ce40761986"},
     "v1-b1": {"noisy_student": "8f44bff58fc5ef99baa3f163b3f5c5e8", "imagenet": "a967f7be55a0125c898d650502c0cfd0"},
@@ -56,6 +58,7 @@ def inverted_residual_block(
     se_activation=None,  # None for same with activation
     se_divisor=1,  # 8 for mobilenetv3
     se_limit_round_down=0.9,  # 0.95 for fbnet
+    use_global_context_instead_of_se=False,
     activation="swish",
     name=None,
 ):
@@ -84,7 +87,11 @@ def inverted_residual_block(
 
     if se_ratio > 0:
         se_activation = activation if se_activation is None else se_activation
-        nn = se_module(nn, se_ratio / expand, divisor=se_divisor, limit_round_down=se_limit_round_down, activation=se_activation, name=name and name + "se_")
+        se_ratio = se_ratio / expand
+        if use_global_context_instead_of_se:
+            nn = global_context_module(nn, use_attn=True, ratio=se_ratio, divisor=1, activation=se_activation, use_bias=True, name=name and name + "gc_")
+        else:
+            nn = se_module(nn, se_ratio, divisor=se_divisor, limit_round_down=se_limit_round_down, activation=se_activation, name=name and name + "se_")
 
     # pw-linear
     if is_fused and expand == 1:
@@ -116,6 +123,7 @@ def EfficientNetV2(
     dropout=0.2,
     first_strides=2,
     is_torch_mode=False,
+    use_global_context_instead_of_se=False,
     drop_connect_rate=0,
     activation="swish",
     classifier_activation="softmax",
@@ -147,6 +155,11 @@ def EfficientNetV2(
     nn = conv2d_no_bias(nn, stem_width, 3, strides=first_strides, padding="same", use_torch_padding=is_torch_mode, name="stem_")
     nn = batchnorm_with_activation(nn, activation=activation, epsilon=bn_eps, name="stem_")
 
+    blocks_kwargs = {  # common for all blocks
+        "is_torch_mode": is_torch_mode,
+        "use_global_context_instead_of_se": use_global_context_instead_of_se,
+    }
+
     pre_out = stem_width
     global_block_id = 0
     total_blocks = sum(depthes)
@@ -163,7 +176,7 @@ def EfficientNetV2(
             shortcut = True if out == pre_out and stride == 1 else False
             block_drop_rate = drop_connect_rate * global_block_id / total_blocks
             nn = inverted_residual_block(
-                nn, out, stride, expand, shortcut, kernel_size, block_drop_rate, se_ratio, cur_is_fused, is_torch_mode, activation=activation, name=name
+                nn, out, stride, expand, shortcut, kernel_size, block_drop_rate, se_ratio, cur_is_fused, **blocks_kwargs, activation=activation, name=name
             )
             pre_out = out
             global_block_id += 1
@@ -252,7 +265,7 @@ def EfficientNetV2B3(input_shape=(300, 300, 3), num_classes=1000, dropout=0.3, c
     return EfficientNetV2(**locals(), model_name="efficientnet_v2-b3", **kwargs)
 
 
-def EfficientNetV2T(input_shape=(320, 320, 3), num_classes=1000, dropout=0.2, classifier_activation="softmax", pretrained="imagenet", **kwargs):
+def EfficientNetV2T(input_shape=(288, 288, 3), num_classes=1000, dropout=0.2, classifier_activation="softmax", pretrained="imagenet", **kwargs):
     # width 1.4 * 0.8, depth 1.8 * 0.9, from timm
     is_torch_mode = True
     out_channels = [24, 40, 48, 104, 128, 208]
@@ -262,6 +275,17 @@ def EfficientNetV2T(input_shape=(320, 320, 3), num_classes=1000, dropout=0.2, cl
     return EfficientNetV2(**locals(), model_name="efficientnet_v2-t", **kwargs)
 
 
+def EfficientNetV2T_GC(input_shape=(288, 288, 3), num_classes=1000, dropout=0.2, classifier_activation="softmax", pretrained="imagenet", **kwargs):
+    # width 1.4 * 0.8, depth 1.8 * 0.9, from timm
+    is_torch_mode = True
+    use_global_context_instead_of_se = True
+    out_channels = [24, 40, 48, 104, 128, 208]
+    depthes = [2, 4, 4, 6, 9, 14]
+    first_conv_filter = kwargs.pop("first_conv_filter", 24)
+    output_conv_filter = kwargs.pop("output_conv_filter", 1024)
+    return EfficientNetV2(**locals(), model_name="efficientnet_v2-t-gc", **kwargs)
+
+
 def EfficientNetV2S(input_shape=(384, 384, 3), num_classes=1000, dropout=0.2, classifier_activation="softmax", pretrained="imagenet", **kwargs):
     # width 1.4, depth 1.8
     out_channels = [24, 48, 64, 128, 160, 256]
