@@ -16,6 +16,7 @@ class TorchModelInterf:
 
     def __call__(self, imgs):
         # print(imgs.shape, imgs[0])
+        imgs = imgs.numpy() if hasattr(imgs, "numpy") else imgs
         output = self.model(self.torch.from_numpy(imgs).permute([0, 3, 1, 2]).to(self.device).float())
         return output.cpu().detach().numpy()
 
@@ -67,7 +68,7 @@ class TFLiteModelInterf:
 
 
 def evaluation(
-    model, data_name="imagenet2012", input_shape=None, batch_size=64, central_crop=1.0, resize_method="bicubic", antialias=False, rescale_mode="auto"
+    model, data_name="imagenet2012", input_shape=None, batch_size=64, central_crop=1.0, resize_method="bicubic", antialias=True, rescale_mode="auto"
 ):
     from tqdm import tqdm
     import numpy as np
